@@ -44,7 +44,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.20
  */
-#define GTK_SOURCE_MINOR_VERSION (0)
+#define GTK_SOURCE_MINOR_VERSION (2)
 
 /**
  * GTK_SOURCE_MICRO_VERSION:
@@ -73,7 +73,7 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_CHECK_VERSION(major, minor, micro) \
 	(GTK_SOURCE_MAJOR_VERSION > (major) || \
-	(GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION > ((gint) (minor))) || \
+	(GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION > (minor)) || \
 	(GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION == (minor) && \
 	 GTK_SOURCE_MICRO_VERSION >= (micro)))
 
@@ -233,7 +233,17 @@ G_BEGIN_DECLS
  *
  * Since: 5.0
  */
-#define GTK_SOURCE_VERSION_5_0 (G_ENCODE_VERSION (4, 90))
+#define GTK_SOURCE_VERSION_5_0 (G_ENCODE_VERSION (5, 0))
+
+/**
+ * GTK_SOURCE_VERSION_5_2:
+ *
+ * A macro that evaluates to the 5.2 version of GtkSourceView,
+ * in a format that can be used by the C pre-processor.
+ *
+ * Since: 5.2
+ */
+#define GTK_SOURCE_VERSION_5_2 (G_ENCODE_VERSION (5, 2))
 
 /* Define GTK_SOURCE_VERSION_CUR_STABLE */
 #ifndef __GTK_DOC_IGNORE__
@@ -570,12 +580,20 @@ G_BEGIN_DECLS
 
 #ifndef __GTK_DOC_IGNORE__
 #if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_0
-#define GTK_SOURCE_AVAILABLE_IN_5_0 G_UNAVAILABLE(4, 90) _GTK_SOURCE_EXTERN
+#define GTK_SOURCE_AVAILABLE_IN_5_0 G_UNAVAILABLE(5, 0) _GTK_SOURCE_EXTERN
 #else
 #define GTK_SOURCE_AVAILABLE_IN_5_0 _GTK_SOURCE_EXTERN
 #endif
 #endif /* __GTK_DOC_IGNORE__ */
 
+#ifndef __GTK_DOC_IGNORE__
+#if GTK_SOURCE_VERSION_MAX_ALLOWED < GTK_SOURCE_VERSION_5_2
+#define GTK_SOURCE_AVAILABLE_IN_5_2 G_UNAVAILABLE(5, 2) _GTK_SOURCE_EXTERN
+#else
+#define GTK_SOURCE_AVAILABLE_IN_5_2 _GTK_SOURCE_EXTERN
+#endif
+#endif /* __GTK_DOC_IGNORE__ */
+
 GTK_SOURCE_AVAILABLE_IN_3_20
 guint    gtk_source_get_major_version (void);
 GTK_SOURCE_AVAILABLE_IN_3_20
